import Image from "next/image";
import { Suspense } from "react";

import { AboutLoadingSkeleton } from "@/components/common/loading-skeleton";
import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import { ContactButtons } from "@/components/sections/contact/contact-buttons";
import ContactForm from "@/components/sections/contact/contact-form";
import { PageBreadcrumb } from "@/components/shared/page-breadcrump";
import { ImageBaseUrl } from "@/configs/api";
import { getClient } from "@/lib/react-query";
import { fetchBasicInfo } from "@/servers/actions/basicinfo-action";
import type { LocaleParams } from "@/types/params";
import { dehydrate, HydrationBoundary } from "@tanstack/react-query";

export default async function AboutPage({ params }: { params: LocaleParams }) {
	const { locale } = await params;

	const breadcrumbItems = [
		{
			href: "/",
			label: {
				en: "Home",
				ar: "الرئيسية",
			},
		},
		{
			href: "/contact",
			label: {
				en: "Contact Us",
				ar: "تواصل معنا",
			},
		},
	];

	const queryClient = getClient();
	await Promise.all([
		queryClient.prefetchQuery({ queryKey: ["basicInfo"], queryFn: fetchBasicInfo }),
	]);

	const _data = queryClient.getQueryData<any>(["basicInfo"]);

	const _contact = _data?.data?.pages_headers?.find((val: any) => val.page == "contact us");

	return (
		<HydrationBoundary state={dehydrate(queryClient)}>
			<main className="min-h-screen">
				<Header />
				<Suspense fallback={<AboutLoadingSkeleton locale={locale} />}>
					<PageBreadcrumb
						backgroundImage={ImageBaseUrl + _contact?.page_image}
						subtitle={{
							en: _contact?.text?.en,
							ar: _contact?.text?.ar,
						}}
						title={{
							en: _contact?.description?.en,
							ar: _contact?.description?.ar,
						}}
						breadcrumbItems={breadcrumbItems}
						locale={locale}
					/>
					<ContactForm locale={locale} />
					<div className="container mx-auto my-20 max-w-7xl">
						<ContactButtons />
					</div>
					<div className="relative mt-6 h-[569px] w-full">
						<Image
							src={"/images/request-job/map.png"}
							alt=""
							className="object-cover"
							fill
							priority
						/>
					</div>
					<Footer />
				</Suspense>
			</main>
		</HydrationBoundary>
	);
}
